R/bic-core.R
delta_meancovar.Rd
Perturbation matrix for the mean-covariate scheme
delta_meancovar(object, p = 1L)
A fitted BEZI/BEOI gamlss model.
gamlss
Index of the perturbed covariate in the mean design matrix.
A list with the full Delta and its blocks.
Delta