Decomposes the per-observation CNC scores into a contribution from the inflation-probability submodel and a contribution from the conditional-mean/precision submodel, exploiting the information orthogonality of the BIc model. The two contributions sum exactly to the total, with no cross terms.
Arguments
- delta_out
A perturbation-matrix list (e.g. from
delta_caseweights()) with a fullDeltacomponent.- info_out
An information list from
bic_info()withinfo_invandidx.